# Serpapi MCP Server

An MCP Server for the Serpapi API.

## 🛠️ Tool List

This is automatically generated from OpenAPI schema for the Serpapi API.


| Tool | Description |
|------|-------------|
| `search` | Performs an asynchronous search using the SerpApi service and returns formatted search results. |
